PostProcessor

Enum PostProcessor 

pub enum PostProcessor {
    Sum,
    Avg,
    Max,
    Min,
}
Post processing action after a round of dice roll

Example

  • 3d6 default to sum of roll a 6 sides dice 3 times
  • 3d6max means get the max value of those 3 result
  • 3d6min means get the min value of those 3 result
  • 3d6avg means get the avg value of those 3 result

Variants



Sum

get sum of all roll, default action



Avg

get avg value of all roll, will round down(floor) if not divisible



Max

get max value of all roll



Min

get min value of all roll