pub enum PostProcessor {
Sum,
Avg,
Max,
Min,
}Expand description
Post processing action after a round of dice roll
Example
3d6default to sum of roll a 6 sides dice 3 times3d6maxmeans get the max value of those 3 result3d6minmeans get the min value of those 3 result3d6avgmeans get the avg value of those 3 result
Variants
Sum
get sum of all roll, default action
Avg
get avg value of all roll, will round down(floor) if not divisible
Max
get max value of all roll
Min
get min value of all roll